#!/bin/bash
#
# uninstall.sh
#
# Copyright (C) 2011-2013 Cesnet z.s.p.o
#
# Use of this source is governed by a BSD-style license, see LICENSE file.  

VERSION="2.1"

#-------------------------------------------------------------------------------
#				FUNCTIONS
#-------------------------------------------------------------------------------
usage()
{
	echo "Usage: `basename $0` [-d <directory>] [-hV]"
	echo "-d <directory>            uninstallation directory (default: /opt)"
	echo "-h                        print this help"
	echo "-V                        print script version number and exit"
	echo
	echo "Example: # ./`basename $0` -d /opt"
	echo
	echo "Note: You must be root for running this script."
	echo "      For more information about uninstallation process, see README file (section Uninstallation)."
	echo
	exit 0
}


version()
{
	echo "`basename ${0}` - current version is $VERSION"
	exit 0
}


err()
{
	echo "FAILED!"
	cat $err
	rm -rf $err $backup_dir
	echo
	echo "Uninstallation of $package_version package FAILED!!!"
	exit 1
}


err_clean()
{
	echo "FAILED!"
	echo " -> Reverting changes of warden client package ... OK"
	rm -rf ${client_path}/* > /dev/null 2>&1
	cp -R ${backup_dir}/* $client_path
	cat $err
	rm -rf $err $backup_dir
	echo
	echo "Uninstallation of $package_version package FAILED!!!"
	exit 1
}


root_chck()
{
	if [ $UID -ne 0 ]; then
		echo "You must be root for running this script!"
		exit 1
	fi
}


params_chck()
{
	if [ -z $prefix ]; then
		prefix=/opt
		echo "Warning: parameter -d <directory> is not set - default uninstallation directory is ${prefix}!"
	fi
}


obtain_package_version()
{
	if [ -f $old_package_version_file ]; then 
		package_version=`cat $old_package_version_file`
	else
		package_version="unknown"
	fi
}


warden_dir_chck()
{
	echo -n "Checking warden client directory ... "
	if [ ! -d $client_path ]; then
		echo "FAILED!"
		ls $client_path
		exit 1
	else
		echo "OK"
	fi
}


backup()
{
	echo -n "Backing-up warden client directory ... "
	mkdir $backup_dir
	if cp -R ${client_path}/* $backup_dir 2> $err; then
		echo "OK"
	else
		err
	fi
}


uninstall_warden_client()
{
	echo -n "Uninstalling $package_version package ... "
	if rm -rf $client_path 2> $err; then
		echo "OK"
	else
		err_clean
	fi
}

#-------------------------------------------------------------------------------
#				MAIN
#-------------------------------------------------------------------------------

# read input
while getopts "d:Vh" options; do
	case $options in
		d ) prefix=$OPTARG;;
		h ) usage;;
		V ) version;;
		* ) usage;;
	esac
done

# create variables
[[ $prefix == */ ]] && prefix="${prefix%?}" # remove last char (slash) from prefix
client_path="${prefix}/warden-client"
etc="${client_path}/etc"
old_package_version_file="${etc}/package_version"
err="/tmp/warden-err"
backup_dir="/tmp/warden-backup"

# obtain version of installed warden-client package
obtain_package_version

echo
echo "------------------------- Uninstallation process --------------------------------"

# root check
root_chck

# check if $prefix/warden-client directory exist
warden_dir_chck

# make backup of currently installed warden-client package
backup

# do uninstallation
uninstall_warden_client

echo
echo "Uninstallation of $package_version package was SUCCESSFUL!!!"

# cleanup section
rm -rf $err $backup_dir

exit 0
